Use 20-byte libbcc.so.sha1 to store checksum

Change-Id: I1e66e559918426e995b92785666beb7b6a49869d
diff --git a/lib/ExecutionEngine/Compiler.cpp b/lib/ExecutionEngine/Compiler.cpp
index 9d13039..b849505 100644
--- a/lib/ExecutionEngine/Compiler.cpp
+++ b/lib/ExecutionEngine/Compiler.cpp
@@ -246,8 +246,8 @@
      llvm::createLinearScanRegisterAllocator);
 
 #if USE_CACHE
-  // Calculate the SHA1 checksum of libbcc and libRS.
-  calcFileSHA1(sha1LibBCC_SHA1, pathLibBCC_SHA1);
+  // Read in SHA1 checksum of libbcc and libRS.
+  readSHA1(sha1LibBCC_SHA1, sizeof(sha1LibBCC_SHA1), pathLibBCC_SHA1);
 #endif
 
   GlobalInitialized = true;